# 👷 Contributing

There are many ways you can contribute to qpsolvers. Here are some ideas:

- Add a [new solver](https://scaron.info/doc/qpsolvers/developer-notes.html#adding-a-new-solver) to the library, for instance one from the [wish list](https://github.com/qpsolvers/qpsolvers/issues?q=is%3Aissue+is%3Aopen+label%3A%22new+solver%22)
- Describe your use case in [Show and tell](https://github.com/qpsolvers/qpsolvers/discussions/categories/show-and-tell)
- Pick one of the [open issues](https://github.com/qpsolvers/qpsolvers/issues?q=is%3Aissue+is%3Aopen)
- Suggest improvements to the [documentation](https://scaron.info/doc/qpsolvers/)
- Find a case that is [not covered](https://coveralls.io/github/qpsolvers/qpsolvers?branch=master) by unit tests, and add a test for it

If any of these sound interesting, open a corresponding [issue](https://github.com/qpsolvers/qpsolvers/issues) to say you're on it!
